import 'package:flutter_dotenv/flutter_dotenv.dart';
import 'package:migrable/migration.dart';
import 'package:sqflite/sqflite.dart';

class Migrable {
  static void execute(List<Migartion> migrations) async {
    final databasePath = DotEnv().env['DATABASE_PATH'];

    onConfigure(database) async {
      await database.execute('PRAGMA foreign_keys = ON');
    }

    onCreate(database, version) {
      final batch = database.batch();

      migrations.forEach((migration) => {migration.up(batch)});
      batch.commit();
    }

    onUpgrade(database, oldVersion, newVersion) async {
      final batch = database.batch();

      for (var index = oldVersion; index < newVersion; index++) {
        final migration = migrations[index];

        migration.up(batch);
      }

      batch.commit();
    }

    await openDatabase(databasePath,
        version: migrations.length,
        onConfigure: onConfigure,
        onDowngrade: onDatabaseDowngradeDelete,
        onCreate: onCreate,
        onUpgrade: onUpgrade);
  }
}
